@@ -25,6 +25,7 @@ from python_on_whales.components.container.models import (
     Mount,
     NetworkSettings,
 )
+from python_on_whales.exceptions import NoSuchContainer
 from python_on_whales.utils import (
     ValidPath,
     format_dict_for_cli,
@@ -202,13 +203,35 @@ class Container(ReloadableObjectFromJson):
         """
         return ContainerCLI(self.client_config).diff(self)
 
-    def execute(self, command: Union[str, List[str]], detach: bool = False):
+    def execute(
+        self,
+        command: Union[str, List[str]],
+        detach: bool = False,
+        envs: Dict[str, str] = {},
+        env_files: Union[ValidPath, List[ValidPath]] = [],
+        # interactive: bool = False,
+        privileged: bool = False,
+        # tty: bool = False,
+        user: Optional[str] = None,
+        workdir: Optional[ValidPath] = None,
+    ):
         """Execute a command in this container
 
         See the [`docker.container.execute`](../sub-commands/container.md#execute)
         command for information about the arguments.
         """
-        return ContainerCLI(self.client_config).execute(self, command, detach)
+        return ContainerCLI(self.client_config).execute(
+            self,
+            command,
+            detach,
+            envs,
+            env_files,
+            # interactive,
+            privileged,
+            # tty,
+            user,
+            workdir,
+        )
 
     def export(self, output: ValidPath) -> None:
         """Export this container filesystem.
@@ -301,6 +324,15 @@ class Container(ReloadableObjectFromJson):
         """
         return ContainerCLI(self.client_config).stop(self, time)
 
+    def exists(self) -> bool:
+        """Returns `True` if the docker container exists and `False` if it doesn't exists.
+
+        If it doesn't exists, it most likely mean that it was removed.
+
+         See the `docker.container.exists` command for information about the arguments.
+        """
+        return ContainerCLI(self.client_config).exists(self.id)
+
 
 ContainerPath = Tuple[Union[Container, str], ValidPath]
 ValidContainer = Union[Container, str]
@@ -693,6 +725,13 @@ class ContainerCLI(DockerCLICaller):
         container: ValidContainer,
         command: Union[str, List[str]],
         detach: bool = False,
+        envs: Dict[str, str] = {},
+        env_files: Union[ValidPath, List[ValidPath]] = [],
+        # interactive: bool = False,
+        privileged: bool = False,
+        # tty: bool = False,
+        user: Optional[str] = None,
+        workdir: Optional[ValidPath] = None,
     ) -> Optional[str]:
         """Execute a command inside a container
 
@@ -703,14 +742,33 @@ class ContainerCLI(DockerCLICaller):
             command: The command to execute.
             detach: if `True`, returns immediately with `None`. If `False`,
                 returns the command stdout as string.
+            envs: Set environment variables
+            env_files: Read one or more files of environment variables
+            privileged: Give extended privileges to the container.
+            user: Username or UID, format: `"<name|uid>[:<group|gid>]"`
+            workdir: Working directory inside the container
 
         # Returns:
             Optional[str]
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         full_cmd = self.docker_cmd + ["exec"]
 
         full_cmd.add_flag("--detach", detach)
 
+        full_cmd.add_args_list("--env", format_dict_for_cli(envs))
+        full_cmd.add_args_list("--env-file", env_files)
+
+        # TODO: activate interactive and tty
+        # full_cmd.add_flag("--interactive", interactive)
+        full_cmd.add_flag("--privileged", privileged)
+        # full_cmd.add_flag("--tty", tty)
+
+        full_cmd.add_simple_arg("--user", user)
+        full_cmd.add_simple_arg("--workdir", workdir)
+
         full_cmd.append(container)
         for arg in to_list(command):
             full_cmd.append(arg)
@@ -728,16 +786,22 @@ class ContainerCLI(DockerCLICaller):
 
         # Arguments
             container: The container to export.
-            output: The path of the output tar archive.
+            output: The path of the output tar archive. Returning a generator of bytes
+                is not yet implemented.
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
-        full_cmd = self.docker_cmd + [
-            "container",
-            "--output",
-            output,
-            "export",
-            container,
-        ]
-        run(full_cmd)
+        full_cmd = self.docker_cmd + ["container", "export"]
+        full_cmd.add_simple_arg("--output", output)
+
+        full_cmd.append(container)
+
+        if output is None:
+            # we must return a generator of bytes
+            raise NotImplementedError
+        else:
+            run(full_cmd)
 
     @overload
     def inspect(self, x: str) -> Container:
@@ -757,6 +821,9 @@ class ContainerCLI(DockerCLICaller):
         # Returns:
             A `python_on_whales.Container` object or a list of those
             if a list of IDs was passed as input.
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
 
         if isinstance(x, list):
@@ -776,6 +843,10 @@ class ContainerCLI(DockerCLICaller):
         # Arguments
             containers: One or more containers to kill
             signal: The signal to send the container
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
+
         """
         containers = to_list(containers)
         if not containers:
@@ -815,6 +886,9 @@ class ContainerCLI(DockerCLICaller):
 
         # Returns
             `str`
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         full_cmd = self.docker_cmd + ["container", "logs"]
         full_cmd.add_flag("--details", details)
@@ -854,6 +928,9 @@ class ContainerCLI(DockerCLICaller):
 
         # Arguments
             containers: One or more containers to pause
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         containers = to_list(containers)
         if not containers:
@@ -884,6 +961,9 @@ class ContainerCLI(DockerCLICaller):
         # Arguments
             container: The container to rename
             new_name: The new name of the container.
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         full_cmd = self.docker_cmd + ["container", "rename", str(container), new_name]
         run(full_cmd)
@@ -901,6 +981,9 @@ class ContainerCLI(DockerCLICaller):
             containers: One or more containers to restart
             time: Amount of to wait for stop before killing the container (default 10s).
                 If `int`, the unit is seconds.
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         containers = to_list(containers)
         if not containers:
@@ -932,6 +1015,9 @@ class ContainerCLI(DockerCLICaller):
             containers: One or more containers.
             force: Force the removal of a running container (uses SIGKILL)
             volumes: Remove anonymous volumes associated with the container
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         containers = to_list(containers)
         if not containers:
@@ -1447,6 +1533,9 @@ class ContainerCLI(DockerCLICaller):
         # Arguments
             containers: One or a list of containers.
             time: Seconds to wait for stop before killing a container (default 10)
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         containers = to_list(containers)
         if not containers:
@@ -1479,6 +1568,9 @@ class ContainerCLI(DockerCLICaller):
 
         # Arguments
             x: One or more containers (name, id or `python_on_whales.Container` object).
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         x = to_list(x)
         if not x:
@@ -1531,6 +1623,9 @@ class ContainerCLI(DockerCLICaller):
                 to enable unlimited swap.
             pids_limit: Tune container pids limit (set `-1` for unlimited)
             restart: Restart policy to apply when a container exits (default "no")
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         x = to_list(x)
         if not x:
@@ -1600,6 +1695,9 @@ class ContainerCLI(DockerCLICaller):
         # [8, 10]
         docker.container.remove([cont_1, cont_2])
         ```
+
+        # Raises
+            `python_on_whales.exceptions.NoSuchContainer` if the container does not exists.
         """
         if x == []:
             # nothing to do
@@ -1613,6 +1711,22 @@ class ContainerCLI(DockerCLICaller):
             full_cmd.append(x)
             return int(run(full_cmd))
 
+    def exists(self, x: str) -> bool:
+        """Returns `True` if the container exists. `False` otherwise.
+
+         It's just calling `docker.container.inspect(...)` and verifies that it doesn't throw
+         a `python_on_whales.exceptions.NoSuchContainer`.
+
+        # Returns
+            A `bool`
+        """
+        try:
+            self.inspect(x)
+        except NoSuchContainer:
+            return False
+        else:
+            return True
+
 
 class ContainerStats:
     def __init__(self, json_dict: Dict[str, Any]):
